Posttest
-----------------------------------------------------

Please try to solve each of the following problems. This test is **ungraded**. 

Please do not ask for external help and try your best to finish it! It is **OK** to not know the correct answers!

Problems
==============

.. selectquestion:: fl-post-upper-center-ac
   :fromid: upper_center
   :points: 10

.. selectquestion:: fl-post-is-descending
   :fromid: prestest_is_ascending_ac-post
   :points: 10

.. selectquestion:: fl-post-sum67
   :fromid: fuct_ac_ll_sum67_fix
   :points: 10

.. selectquestion:: fl-post-lst_loop_two
   :fromid: lst_two_loop_post
   :points: 10

Feedback
==================================

.. shortanswer:: fl-posttest-sa

   Please provide feedback here. Please share any comments, problems, or suggestions.

Thank You 🤗
============================
🎉 Thank you so much for taking part in this study! 

🙏 We appreciate your contribution to help more students become successful in computing courses in a low-cost, scalable, and easily
adopted way!
